%global minorver 20120928

Name:           jenkins-commons-jelly
Version:        1.1.20120928
Release:        9%{?dist}
Summary:        Open and customizable XML processing engine

License:        ASL 2.0
URL:            https://github.com/jenkinsci/jelly

# ./generate-sources.sh
Source0:        jenkins-commons-jelly-%{version}-clean.tar.gz

# Do not run tests for xml jelly tag (missing dep)
Patch0:         0001-Do-not-run-tests-for-jelly-tags-xml.patch
Patch1:         0002-Fix-build.xml-for-jelly-tags-fmt.patch
Patch2:         0003-Fix-build.xml-for-jelly-tags-define.patch

BuildRequires:  maven-local
BuildRequires:  mvn(commons-beanutils:commons-beanutils)
BuildRequires:  mvn(commons-cli:commons-cli)
BuildRequires:  mvn(commons-collections:commons-collections)
BuildRequires:  mvn(commons-discovery:commons-discovery)
BuildRequires:  mvn(commons-lang:commons-lang)
BuildRequires:  mvn(dom4j:dom4j)
BuildRequires:  mvn(javax.servlet:servlet-api)
BuildRequires:  mvn(jaxen:jaxen)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.taglibs:taglibs-standard-spec)
BuildRequires:  mvn(org.jenkins-ci:commons-jexl)

BuildArch:      noarch

%description
Jelly is a tool for turning XML into executable code. It's a Java
and XML based scripting and processing engine. A Jelly script
is an XML document which gets parsed into a Script.
The script can then be ran to produce dynamic XML events
which can then be turned into text, XML, HTML etc. Rather like Velocity,
the XML can contain expressions to make the output dynamic
and can work with a variable context.

This package contains slightly modified version of the library
used in Jenkins project.

%package        javadoc
Summary:        Javadoc for %{name}

%description    javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q

%patch0 -p1
%patch1 -p1
%patch2 -p1

# We don't have this extension
%pom_xpath_remove "pom:extension[pom:artifactId[text()='wagon-svn']]"

# We don't have this in Fedora
%pom_remove_dep forehead:forehead
# Upstream uses commons-cli 1.0 which pulls in commons-lang
# Newest commons-cli 1.2 doesn't require commons-lang anymore
%pom_add_dep "commons-lang:commons-lang"

%pom_change_dep javax.servlet:jstl org.apache.taglibs:taglibs-standard-spec

# Fix line endings
sed -i 's/\r//' LICENSE.txt NOTICE.txt README.txt RELEASE-NOTES.txt \
  README-binary-dist.txt short-license.txt

%build
%mvn_build

# build few more artifacts in jelly-tags/ directory (these use ant)
cpjars="xalan-j2 jenkins-jexl/commons-jexl xml-commons-apis \
        apache-commons-beanutils apache-commons-collections \
        apache-commons-logging dom4j jaxen xerces-j2 junit"

for tag in xml fmt define; do
  mkdir -p jelly-tags/${tag}/target/lib
  build-jar-repository jelly-tags/${tag}/target/lib ${cpjars}
  ln -s ../../../../target/commons-jelly-1.1-jenkins-%{minorver}.jar \
        jelly-tags/${tag}/target/lib/commons-jelly-%{version}.jar

  ant -Dnoget=1 -f jelly-tags/${tag}/build.xml
  %mvn_artifact commons-jelly:commons-jelly-tags-${tag}:::1.0 \
                jelly-tags/${tag}/target/commons-jelly-tags-${tag}-*-SNAPSHOT.jar
done

%install
%mvn_install

%files -f .mfiles
%doc LICENSE.txt NOTICE.txt README.txt RELEASE-NOTES.txt short-license.txt
%doc README-binary-dist.txt
%dir %{_javadir}/%{name}
%files javadoc -f .mfiles-javadoc
%doc LICENSE.txt short-license.txt

%changelog
* Wed Jul 01 2015 Michal Srb <msrb@redhat.com> - 1.1.20120928-9
- Build against jenkins-jexl

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.20120928-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Mar 12 2015 Michal Srb <msrb@redhat.com> - 1.1.20120928-7
- Migrate to tomcat-taglibs-standard

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.20120928-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Mar 04 2014 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.1.20120928-5
- Use Requires: java-headless rebuild (#1067528)

* Thu Dec 05 2013 Michal Srb <msrb@redhat.com> - 1.1.20120928-4
- Build more artifacts

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.20120928-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri May 17 2013 Michal Srb <msrb@redhat.com> - 1.1.20120928-2
- More verbose spec
- Do not install README-like files with javadoc package

* Mon May 06 2013 Michal Srb <msrb@redhat.com> - 1.1.20120928-1
- Initial package

